@@ -1,52 +1,33 @@
 from aws_cdk import core, aws_iam as _iam
-from aws_cdk.core import Tags
-from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
+
 
 class ServiceUserForStaticAssets(core.Construct):
     """Construct to create the Service User to deploy the project static files from a CD/CI pipeline
 
     Args:
-        id (str): the logical id of the newly created resource
-        
-        app_name (str): The application name. This will be used to generate the 'ApplicationName' tag for CSI compliancy. The ID of the application. This must be unique for each system, as it will be used to calculate the AWS costs of the system
+        app_name (str): The application name. This will be used to generate the 'ApplicationName' tag for CSI compliancy. The ID of the application. This must be unique for each system, as it will be used to calculate the AWS costs of the systen
 
         environment (str): Specify the environment in which you want to deploy you system. Allowed values: Development, QA, Production, SharedServices 
 
         environments_parameters (dict): The dictionary containing the references to CSI AWS environments. This will simplify the environment promotions and enable a parametric development of the infrastructures.
 
-        s3_bucket_name (str): The S3 Bucket in which the application code-base is stored
+        s3_assets_bucket_name (str): The S3 Bucket in which the application assets are stored
+
+        s3_code_bucket_name (str): The S3 Bucket in which the application code-base is stored
 
     """
-    @property
-    def service_user(self):
-        """Returns the Service User object
-
-        Returns:
-            aws_cdk.aws_iam.User: The Service User object
-        """
-        return self._service_user
-
     def __init__(
         self,
         scope: core.Construct,
         id: str,
-        app_name,
-        environment,
-        environments_parameters,
-        s3_bucket_name=None,
+        app_name=None,
+        environment=None,
+        s3_code_bucket_name=None,
+        s3_assets_bucket_name=None,
+        environments_parameters=None,
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
-        environment = normalize_environment_parameter(environment)
-
-        # Apply mandatory tags
-        Tags.of(self).add("ApplicationName", app_name.lower().strip())
-        Tags.of(self).add("Environment", environment)
-
-        # Apply FAO CDK tags
-        Tags.of(self).add("fao-cdk-construct", "service_user_for_static_assets")
-        Tags.of(core.Stack.of(self)).add("fao-cdk-version", get_version())
-        Tags.of(core.Stack.of(self)).add("fao-cdk", "true")
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
 
@@ -58,14 +39,14 @@ class ServiceUserForStaticAssets(core.Construct):
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create AWS resources
 
-        self._service_user = _iam.User(
+        service_user = _iam.User(
             self,
             "service_user",
             managed_policies=None,
-            user_name="SRVUSR-" + app_name + "_" + environment + "_static_assets",
+            user_name="SRVUSR-" + app_name + "_" + environment + "_conf",
         )
 
-        self._service_user.add_managed_policy(
+        service_user.add_managed_policy(
             _iam.ManagedPolicy(
                 self,
                 "service_user_policies",
@@ -94,24 +75,13 @@ class ServiceUserForStaticAssets(core.Construct):
                         actions=["s3:ListBucket*"],
                         resources=["arn:aws:s3:::" + aws_account["s3_config_bucket"]],
                     ),
-                    _iam.PolicyStatement(
-                        actions=[
-                            "kms:GenerateDataKey",
-                            "kms:Decrypt",
-                        ],
-                        resources=["*"],
-                        conditions={
-                                "ForAnyValue:StringLike": {
-                                    "aws:ResourceTag/ApplicationName": app_name
-                                }
-                            },
-                    ),
                 ],
             )
         )
 
-        if s3_bucket_name:
-            self._service_user.add_managed_policy(
+        # S3 Code bucket permissions
+        if s3_code_bucket_name:
+            service_user.add_managed_policy(
                 _iam.ManagedPolicy(
                     self,
                     "service_user_s3_code_bucket_policies",
@@ -120,10 +90,28 @@ class ServiceUserForStaticAssets(core.Construct):
                         _iam.PolicyStatement(
                             actions=["s3:*"],
                             resources=[
-                                "arn:aws:s3:::" + s3_bucket_name,
-                                "arn:aws:s3:::" + s3_bucket_name + "/*",
+                                "arn:aws:s3:::" + s3_code_bucket_name,
+                                "arn:aws:s3:::" + s3_code_bucket_name + "/*",
                             ],
                         ),
                     ],
                 )
-            )
\ No newline at end of file
+            )
+
+            # S3 Assets bucket permissions
+        if s3_assets_bucket_name:
+            service_user.add_managed_policy(
+                _iam.ManagedPolicy(
+                    self,
+                    "service_user_s3_assets_bucket_policies",
+                    statements=[
+                        _iam.PolicyStatement(
+                            actions=["s3:*"],
+                            resources=[
+                                "arn:aws:s3:::" + s3_assets_bucket_name,
+                                "arn:aws:s3:::" + s3_assets_bucket_name + "/*",
+                            ],
+                        ),
+                    ],
+                )
+            )
